PCB Environment: IPoint_3 Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
IPoint_3 Class Reference

## Public Member Functions
constexpr | IPoint_3 (int X, int Y, int Z)
| IPoint_3 (const IVector_3 &v)
| IPoint_3 (const int *v)
| IPoint_3 (const uint *v)
IPoint_3 & | operator= (const IPoint_3 &P)
bool | operator== (const IPoint_3 &P) const
bool | operator!= (const IPoint_3 &P) const
bool | isPositive () const
uint | index (const IVector_3 &size) const
IPoint_2 | xy () const
IPoint_3 | operator+ (const IVector_3 &v) const
IPoint_3 | operator- (const IVector_3 &v) const
IVector_3 | operator- (const IPoint_3 &P) const
IPoint_3 & | operator+= (const IVector_3 &v)
IPoint_3 & | operator-= (const IVector_3 &v)
IVector_3 | vector () const

## Data Fields
int32_t | x
int32_t | y
int32_t | z

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Math/IPoint3.hpp